==> core-components-file-upload-item-6.2.3.tgz: package/modern/components/content/components/content-subtitle/content-subtitle.js <==
import React, { useContext } from 'react';
import cn from 'classnames';
import { Text } from '@alfalab/core-components-typography/modern';
import { MAX_PROGRESS_BAR_VALUE } from '../../../../const/progress-bar.js';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isErrorStatus, isUploadingStatus, humanFileSize, isSuccessStatus, isUploadedStatus } from '../../../../utils.js';
import { isError } from '../../utils/isError.js';
import { ContentError } from '../content-error/content-error.js';

const styles = {"subtitle":"file-upload-item__subtitle_1ocf9","truncate":"file-upload-item__truncate_1ocf9","size":"file-upload-item__size_1ocf9"};
require('./content-subtitle.css')

const ContentSubtitle = () => {
    const { uploadStatus, subtitle, uploadDate, size, truncate, showRestore, error, progressBar } = useContext(FileUploadItemContext);
    const shouldShownError = isErrorStatus(uploadStatus) || isError(error);
    const showMeta = !showRestore && (isSuccessStatus(uploadStatus) || isUploadedStatus(uploadStatus));
    // валидация progressBar (не должен превышать 100 и быть меньше 0)
    const validateProgressBarValue = (progressValue) => {
        if (progressValue === undefined) {
            return 0;
        }
        return Math.min(Math.max(progressValue, 0), MAX_PROGRESS_BAR_VALUE);
    };
    const validProgressBar = validateProgressBarValue(progressBar);
    // uploading status
    if (isUploadingStatus(uploadStatus)) {
        return (React.createElement(Text, { view: 'primary-small', color: 'secondary' },
            "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430",
            '\u00A0',
            Math.floor(validProgressBar),
            "%"));
    }
    // error status
    if (shouldShownError) {
        return React.createElement(ContentError, null);
    }
    // success status
    if (showMeta) {
        return (React.createElement("div", null,
            size && (React.createElement(Text, { className: styles.size, view: 'primary-small', color: 'secondary' }, humanFileSize(size))),
            uploadDate && (React.createElement(Text, { view: 'primary-small', color: 'secondary' }, uploadDate))));
    }
    // restore status
    if (showRestore) {
        return (React.createElement(Text, { view: 'primary-small', color: 'tertiary' }, "\u0424\u0430\u0439\u043B \u0443\u0434\u0430\u043B\u0435\u043D"));
    }
    return (React.createElement(Text, { className: cn(styles.subtitle, {
            [styles.truncate]: truncate,
        }), view: 'primary-small', color: 'secondary' }, subtitle));
};

export { ContentSubtitle };

==> core-components-file-upload-item-6.2.5.tgz: package/modern/components/content/components/content-subtitle/content-subtitle.js <==
import React, { useContext } from 'react';
import cn from 'classnames';
import { Text } from '@alfalab/core-components-typography/modern';
import { MAX_PROGRESS_BAR_VALUE } from '../../../../const/progress-bar.js';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isErrorStatus, isUploadingStatus, humanFileSize, isSuccessStatus, isUploadedStatus } from '../../../../utils.js';
import { isError } from '../../utils/isError.js';
import { ContentError } from '../content-error/content-error.js';

const styles = {"subtitle":"file-upload-item__subtitle_k6i45","truncate":"file-upload-item__truncate_k6i45","size":"file-upload-item__size_k6i45"};
require('./content-subtitle.css')

const ContentSubtitle = () => {
    const { uploadStatus, subtitle, uploadDate, size, truncate, showRestore, error, progressBar } = useContext(FileUploadItemContext);
    const shouldShownError = isErrorStatus(uploadStatus) || isError(error);
    const showMeta = !showRestore && (isSuccessStatus(uploadStatus) || isUploadedStatus(uploadStatus));
    // валидация progressBar (не должен превышать 100 и быть меньше 0)
    const validateProgressBarValue = (progressValue) => {
        if (progressValue === undefined) {
            return 0;
        }
        return Math.min(Math.max(progressValue, 0), MAX_PROGRESS_BAR_VALUE);
    };
    const validProgressBar = validateProgressBarValue(progressBar);
    // uploading status
    if (isUploadingStatus(uploadStatus)) {
        return (React.createElement(Text, { view: 'primary-small', color: 'secondary' },
            "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430",
            '\u00A0',
            Math.floor(validProgressBar),
            "%"));
    }
    // error status
    if (shouldShownError) {
        return React.createElement(ContentError, null);
    }
    // success status
    if (showMeta) {
        return (React.createElement("div", null,
            size && (React.createElement(Text, { className: styles.size, view: 'primary-small', color: 'secondary' }, humanFileSize(size))),
            uploadDate && (React.createElement(Text, { view: 'primary-small', color: 'secondary' }, uploadDate))));
    }
    // restore status
    if (showRestore) {
        return (React.createElement(Text, { view: 'primary-small', color: 'tertiary' }, "\u0424\u0430\u0439\u043B \u0443\u0434\u0430\u043B\u0435\u043D"));
    }
    return (React.createElement(Text, { className: cn(styles.subtitle, {
            [styles.truncate]: truncate,
        }), view: 'primary-small', color: 'secondary' }, subtitle));
};

export { ContentSubtitle };
